@@ -1,6 +1,6 @@
 from anastruct.fem.system import SystemElements
 
-ss = SystemElements(plot_backend="plotly")
+ss = SystemElements()
 ss.add_element([[0, 0], [1, 0]])
 ss.add_element([2, 0])
 
@@ -10,4 +10,4 @@ ss.point_load(2, Fy=-1000)
 ss.solve()
 ss.show_structure()
 ss.show_bending_moment()
-ss.show_displacement()
\ No newline at end of file
+ss.show_displacement()
