@@ -1,7 +1,7 @@
-import numpy as np
 import math
-import matplotlib.pyplot as plt
-import matplotlib.patches as mpatches
+import numpy as np
+import matplotlib.pyplot as plt  # type: ignore
+import matplotlib.patches as mpatches  # type: ignore
 from anastruct.basic import find_nearest, rotate_xy
 from anastruct.fem.plotter.values import (
     PlottingValues,
@@ -22,7 +22,9 @@ class Plotter(PlottingValues):
         self.system = system
         self.one_fig = None
         self.max_q = 0
+        self.max_qn = 0
         self.max_system_point_load = 0
+        self.fig = None
 
     def __start_plot(self, figsize):
         plt.close("all")
@@ -60,6 +62,22 @@ class Plotter(PlottingValues):
             )
             self.one_fig.add_patch(support_patch)
 
+    def __rotational_support_patch(self, max_val):
+        """
+        :param max_val: max scale of the plot
+        """
+        width = height = PATCH_SIZE * max_val
+        for node in self.system.supports_rotational:
+            support_patch = mpatches.Rectangle(
+                (node.vertex.x - width * 0.5, -node.vertex.z - width * 0.5),
+                width,
+                height,
+                color="r",
+                zorder=9,
+                fill=False,
+            )
+            self.one_fig.add_patch(support_patch)
+
     def __roll_support_patch(self, max_val):
         """
         :param max_val: max scale of the plot
@@ -68,12 +86,17 @@ class Plotter(PlottingValues):
         count = 0
         for node in self.system.supports_roll:
             direction = self.system.supports_roll_direction[count]
-            x1 = np.cos(np.pi) * radius + node.vertex.x + radius
-            z1 = np.sin(np.pi) * radius + node.vertex.y
-            x2 = np.cos(np.radians(90)) * radius + node.vertex.x + radius
-            z2 = np.sin(np.radians(90)) * radius + node.vertex.y
-            x3 = np.cos(np.radians(270)) * radius + node.vertex.x + radius
-            z3 = np.sin(np.radians(270)) * radius + node.vertex.y
+            rotate = self.system.supports_roll_rotate[count]
+            x1 = np.cos(np.pi) * radius + node.vertex.x + radius  # vertex.x
+            z1 = np.sin(np.pi) * radius + node.vertex.y  # vertex.y
+            x2 = (
+                np.cos(np.radians(90)) * radius + node.vertex.x + radius
+            )  # vertex.x + radius
+            z2 = np.sin(np.radians(90)) * radius + node.vertex.y  # vertex.y + radius
+            x3 = (
+                np.cos(np.radians(270)) * radius + node.vertex.x + radius
+            )  # vertex.x + radius
+            z3 = np.sin(np.radians(270)) * radius + node.vertex.y  # vertex.y - radius
 
             triangle = np.array([[x1, z1], [x2, z2], [x3, z3]])
 
@@ -87,6 +110,17 @@ class Plotter(PlottingValues):
                     triangle[1:, 1] - 0.5 * radius * np.cos(angle),
                     color="r",
                 )
+                if not rotate:
+                    rect_patch = mpatches.RegularPolygon(
+                        (node.vertex.x, node - node.vertex.y),
+                        numVertices=4,
+                        radius=radius,
+                        orientation=angle,
+                        color="r",
+                        zorder=9,
+                        fill=False,
+                    )
+                    self.one_fig.add_patch(rect_patch)
 
             elif direction == 2:  # horizontal roll
                 support_patch = mpatches.RegularPolygon(
@@ -101,6 +135,16 @@ class Plotter(PlottingValues):
                 self.one_fig.plot(
                     [node.vertex.x - radius, node.vertex.x + radius], [y, y], color="r"
                 )
+                if not rotate:
+                    rect_patch = mpatches.Rectangle(
+                        (node.vertex.x - radius / 2, -node.vertex.z - radius / 2),
+                        radius,
+                        radius,
+                        color="r",
+                        zorder=9,
+                        fill=False,
+                    )
+                    self.one_fig.add_patch(rect_patch)
             elif direction == 1:  # vertical roll
                 # translate the support to the node
 
@@ -113,6 +157,16 @@ class Plotter(PlottingValues):
                     [y, y + 2 * radius],
                     color="r",
                 )
+                if not rotate:
+                    rect_patch = mpatches.Rectangle(
+                        (node.vertex.x - radius / 2, -node.vertex.z - radius / 2),
+                        radius,
+                        radius,
+                        color="r",
+                        zorder=9,
+                        fill=False,
+                    )
+                    self.one_fig.add_patch(rect_patch)
             count += 1
 
     def __rotating_spring_support_patch(self, max_val):
@@ -193,31 +247,25 @@ class Plotter(PlottingValues):
         x1;y1  element    x2;y2
         """
 
-        for q_id in self.system.loads_q.keys():
-            el = self.system.element_map[q_id]
-            if el.q_load > 0:
-                direction = 1
-            else:
-                direction = -1
-
-            h = 0.05 * max_val * abs(el.q_load) / self.max_q
-            x1 = el.vertex_1.x
-            y1 = el.vertex_1.y
-            x2 = el.vertex_2.x
-            y2 = el.vertex_2.y
-
-            if el.q_direction == "y":
-                ai = 0
-            elif el.q_direction == "x":
-                ai = 0.5 * np.pi
-            else:
-                ai = -el.angle
+        def __plot_patch(
+            h1,
+            h2,
+            x1,
+            y1,
+            x2,
+            y2,
+            ai,
+            qi,
+            q,
+            direction,
+            el_angle,  # pylint: disable=unused-argument
+        ):
 
             # - value, because the positive z of the system is opposite of positive y of the plotter
-            xn1 = x1 + np.sin(ai) * h * direction
-            yn1 = y1 + np.cos(ai) * h * direction
-            xn2 = x2 + np.sin(ai) * h * direction
-            yn2 = y2 + np.cos(ai) * h * direction
+            xn1 = x1 + np.sin(ai) * h1 * direction
+            yn1 = y1 + np.cos(ai) * h1 * direction
+            xn2 = x2 + np.sin(ai) * h2 * direction
+            yn2 = y2 + np.cos(ai) * h2 * direction
             coordinates = ([x1, xn1, xn2, x2], [y1, yn1, yn2, y2])
             self.one_fig.plot(*coordinates, color="g")
             rec = plt.Polygon(np.vstack(coordinates).T, color="g", alpha=0.3)
@@ -225,26 +273,96 @@ class Plotter(PlottingValues):
 
             if verbosity == 0:
                 # arrow
-                xa_1 = (x2 - x1) * 0.2 + x1 + np.sin(ai) * 0.8 * h * direction
-                ya_1 = (y2 - y1) * 0.2 + y1 + np.cos(ai) * 0.8 * h * direction
-                len_x = np.sin(ai - np.pi) * 0.6 * h * direction
-                len_y = np.cos(ai - np.pi) * 0.6 * h * direction
-                xt = xa_1 + np.sin(-el.angle) * 0.4 * h * direction
-                yt = ya_1 + np.cos(-el.angle) * 0.4 * h * direction
+                # pos = np.sqrt(((y1 - y2) ** 2) + ((x1 - x2) ** 2))
+                # cg = ((pos / 3) * (qi + 2 * q)) / (qi + q)
+                # height = math.sin(el_angle) * cg
+                # base = math.cos(el_angle) * cg
+
+                len_x1 = np.sin(ai - np.pi) * 0.6 * h1 * direction
+                len_x2 = np.sin(ai - np.pi) * 0.6 * h2 * direction
+                len_y1 = np.cos(ai - np.pi) * 0.6 * h1 * direction
+                len_y2 = np.cos(ai - np.pi) * 0.6 * h2 * direction
+                step_x = np.linspace(xn1, xn2, 11)
+                step_y = np.linspace(yn1, yn2, 11)
+                step_len_x = np.linspace(len_x1, len_x2, 11)
+                step_len_y = np.linspace(len_y1, len_y2, 11)
+                average_h = (h1 + h2) / 2
                 # fc = face color, ec = edge color
-                self.one_fig.arrow(
-                    xa_1,
-                    ya_1,
-                    len_x,
-                    len_y,
-                    head_width=h * 0.25,
-                    head_length=0.2 * h,
-                    ec="g",
-                    fc="g",
-                )
-                self.one_fig.text(
-                    xt, yt, "q=%d" % el.q_load, color="k", fontsize=9, zorder=10
-                )
+                self.one_fig.text(xn1, yn1, f"q={qi}", color="b", fontsize=9, zorder=10)
+                self.one_fig.text(xn2, yn2, f"q={q}", color="b", fontsize=9, zorder=10)
+
+                # add multiple arrows to fill load
+                for counter, step_xi in enumerate(step_x):
+                    if q + qi >= 0:
+                        if counter == 0:
+                            shape = "right"
+                        elif counter == 10:
+                            shape = "left"
+                        else:
+                            shape = "full"
+                    else:
+                        if counter == 0:
+                            shape = "left"
+                        elif counter == 10:
+                            shape = "right"
+                        else:
+                            shape = "full"
+
+                    self.one_fig.arrow(
+                        step_xi,
+                        step_y[counter],
+                        step_len_x[counter],
+                        step_len_y[counter],
+                        head_width=average_h * 0.25,
+                        head_length=0.4
+                        * np.sqrt(step_len_y[counter] ** 2 + step_len_x[counter] ** 2),
+                        ec="k",
+                        fc="k",
+                        shape=shape,
+                    )
+
+        for q_id in self.system.loads_q.keys():
+            el = self.system.element_map[q_id]
+            qi = el.q_load[0]
+            q = el.q_load[1]
+
+            x1 = el.vertex_1.x
+            y1 = el.vertex_1.y
+            x2 = el.vertex_2.x
+            y2 = el.vertex_2.y
+
+            if max(qi, q) > 0:
+                direction = 1
+            else:
+                direction = -1
+
+            h1 = 0.05 * max_val * abs(qi) / self.max_q
+            h2 = 0.05 * max_val * abs(q) / self.max_q
+
+            ai = np.pi / 2 - el.q_angle
+            el_angle = el.angle
+            __plot_patch(h1, h2, x1, y1, x2, y2, ai, qi, q, direction, el_angle)
+
+            if el.q_perp_load[0] != 0 or el.q_perp_load[1] != 0:
+                qi = el.q_perp_load[0]
+                q = el.q_perp_load[1]
+
+                x1 = el.vertex_1.x + np.sin(ai) * h1 * direction * 2
+                y1 = el.vertex_1.y + np.cos(ai) * h1 * direction * 2
+                x2 = el.vertex_2.x + np.sin(ai) * h2 * direction * 2
+                y2 = el.vertex_2.y + np.cos(ai) * h2 * direction * 2
+
+                if max(qi, q) > 0:
+                    direction = 1
+                else:
+                    direction = -1
+
+                h1 = 0.05 * max_val * abs(qi) / self.max_q
+                h2 = 0.05 * max_val * abs(q) / self.max_q
+
+                ai = -el.q_angle
+                el_angle = el.angle
+                __plot_patch(h1, h2, x1, y1, x2, y2, ai, qi, q, direction, el_angle)
 
     @staticmethod
     def __arrow_patch_values(Fx, Fz, node, h):
@@ -256,7 +374,7 @@ class Plotter(PlottingValues):
         :return: Variables for the matplotlib plotter
         """
 
-        F = (Fx ** 2 + Fz ** 2) ** 0.5
+        F = (Fx**2 + Fz**2) ** 0.5
         len_x = Fx / F * h
         len_y = -Fz / F * h
         x = node.vertex.x - len_x * 1.2
@@ -271,7 +389,7 @@ class Plotter(PlottingValues):
 
         for k in self.system.loads_point:
             Fx, Fz = self.system.loads_point[k]
-            F = (Fx ** 2 + Fz ** 2) ** 0.5
+            F = (Fx**2 + Fz**2) ** 0.5
             node = self.system.node_map[k]
             h = 0.1 * max_plot_range * F / self.max_system_point_load
             x, y, len_x, len_y, F = self.__arrow_patch_values(Fx, Fz, node, h)
@@ -288,7 +406,7 @@ class Plotter(PlottingValues):
                 zorder=11,
             )
             if verbosity == 0:
-                self.one_fig.text(x, y, "F=%d" % F, color="k", fontsize=9, zorder=10)
+                self.one_fig.text(x, y, f"F={F}", color="k", fontsize=9, zorder=10)
 
     def __moment_load_patch(self, max_val):
 
@@ -315,7 +433,7 @@ class Plotter(PlottingValues):
             self.one_fig.text(
                 node.vertex.x + h * 0.2,
                 -node.vertex.z + h * 0.2,
-                "T=%d" % v,
+                f"T={v}",
                 color="k",
                 fontsize=9,
                 zorder=10,
@@ -335,7 +453,8 @@ class Plotter(PlottingValues):
         """
         :param show: (boolean) if True, plt.figure will plot.
         :param supports: (boolean) if True, supports are plotted.
-        :param annotations: (boolean) if True, structure annotations are plotted. It includes section name.
+        :param annotations: (boolean) if True, structure annotations are plotted.
+                            It includes section name.
         :return:
         """
         if not gridplot:
@@ -349,9 +468,9 @@ class Plotter(PlottingValues):
         min_y = np.min(y)
 
         center_x = (max_x - min_x) / 2 + min_x + -offset[0]
-        center_y = (max_y - min_y) / 2 + min_x + -offset[1]
+        center_y = (max_y - min_y) / 2 + min_y + -offset[1]
 
-        max_plot_range = max(max_x, max_y)
+        max_plot_range = max(max_x - min_x, max_y - min_y)
         ax_range = max_plot_range * scale
         plusxrange = center_x + ax_range
         plusyrange = center_y + ax_range * figsize[1] / figsize[0]
@@ -370,7 +489,7 @@ class Plotter(PlottingValues):
                 self.one_fig.text(
                     x_val[0] + ax_range,
                     y_val[0] + ax_range,
-                    "%d" % el.node_id1,
+                    f"{el.node_id1}",
                     color="g",
                     fontsize=9,
                     zorder=10,
@@ -378,7 +497,7 @@ class Plotter(PlottingValues):
                 self.one_fig.text(
                     x_val[-1] + ax_range,
                     y_val[-1] + ax_range,
-                    "%d" % el.node_id2,
+                    f"{el.node_id2}",
                     color="g",
                     fontsize=9,
                     zorder=10,
@@ -406,6 +525,7 @@ class Plotter(PlottingValues):
         if supports:
             self.__fixed_support_patch(max_plot_range * scale)
             self.__hinged_support_patch(max_plot_range * scale)
+            self.__rotational_support_patch(max_plot_range * scale)
             self.__roll_support_patch(max_plot_range * scale)
             self.__rotating_spring_support_patch(max_plot_range * scale)
             self.__spring_support_patch(max_plot_range * scale)
@@ -428,7 +548,7 @@ class Plotter(PlottingValues):
         self.one_fig.text(
             x_val[1] - offset,
             y_val[1] + offset,
-            "%s" % round(value_1, digits),
+            f"{round(value_1, digits)}",
             fontsize=9,
             ha="center",
             va="center",
@@ -436,7 +556,7 @@ class Plotter(PlottingValues):
         self.one_fig.text(
             x_val[-2] - offset,
             y_val[-2] + offset,
-            "%s" % round(value_2, digits),
+            f"{round(value_2, digits)}",
             fontsize=9,
             ha="center",
             va="center",
@@ -446,7 +566,7 @@ class Plotter(PlottingValues):
         self.one_fig.text(
             x_val[index],
             y_val[index],
-            "%s" % round(value, digits),
+            f"{round(value, digits)}",
             fontsize=9,
             ha="center",
             va="center",
@@ -460,18 +580,16 @@ class Plotter(PlottingValues):
         digits=2,
         node_results=True,
         fill_polygon=True,
-        color=0
+        color=0,
     ):
         if fill_polygon:
-            rec = plt.Polygon(
-                np.vstack(axis_values).T, color="C{}".format(color), alpha=0.3
-            )
+            rec = plt.Polygon(np.vstack(axis_values).T, color=f"C{color}", alpha=0.3)
             self.one_fig.add_patch(rec)
         # plot force
         x_val = axis_values[0]
         y_val = axis_values[1]
 
-        self.one_fig.plot(x_val, y_val, color="C{}".format(color))
+        self.one_fig.plot(x_val, y_val, color=f"C{color}")
 
         if node_results:
             self._add_node_values(x_val, y_val, force_1, force_2, digits)
@@ -490,24 +608,38 @@ class Plotter(PlottingValues):
         gridplot=False,
     ):
         self.plot_structure(figsize, 1, scale=scale, offset=offset, gridplot=gridplot)
+        con = len(self.system.element_map[1].axial_force)
 
         if factor is None:
             max_force = max(
                 map(
-                    lambda el: max(abs(el.N_1), abs(el.N_2)),
+                    lambda el: max(
+                        abs(el.N_1),
+                        abs(el.N_2),
+                        abs(((el.all_qn_load[0] + el.all_qn_load[1]) / 16) * el.l**2),
+                    ),
                     self.system.element_map.values(),
                 )
             )
             factor = det_scaling_factor(max_force, self.max_val_structure)
 
         for el in self.system.element_map.values():
-            if math.isclose(el.N_1, 0, rel_tol=1e-5, abs_tol=1e-9):
+            if (
+                math.isclose(el.N_1, 0, rel_tol=1e-5, abs_tol=1e-9)
+                and math.isclose(el.N_2, 0, rel_tol=1e-5, abs_tol=1e-9)
+                and math.isclose(el.all_qn_load[0], 0, rel_tol=1e-5, abs_tol=1e-9)
+                and math.isclose(el.all_qn_load[1], 0, rel_tol=1e-5, abs_tol=1e-9)
+            ):
                 continue
             else:
-                axis_values = plot_values_axial_force(el, factor)
+                axis_values = plot_values_axial_force(el, factor, con)
                 color = 1 if el.N_1 < 0 else 0
                 self.plot_result(
-                    axis_values, el.N_1, el.N_2, node_results=not bool(verbosity), color=color
+                    axis_values,
+                    el.N_1,
+                    el.N_2,
+                    node_results=not bool(verbosity),
+                    color=color,
                 )
 
                 point = (el.vertex_2 - el.vertex_1) / 2 + el.vertex_1
@@ -569,10 +701,8 @@ class Plotter(PlottingValues):
                 map(
                     lambda el: max(
                         abs(el.node_1.Ty),
-                        abs(
-                            (el.node_1.Ty - el.node_2.Ty) * 0.5
-                            - 1 / 8 * el.all_q_load * el.l ** 2
-                        ),
+                        abs(el.node_2.Ty),
+                        abs(((el.all_qp_load[0] + el.all_qp_load[1]) / 16) * el.l**2),
                     )
                     if el.type == "general"
                     else 0,
@@ -586,7 +716,8 @@ class Plotter(PlottingValues):
             if (
                 math.isclose(el.node_1.Ty, 0, rel_tol=1e-5, abs_tol=1e-9)
                 and math.isclose(el.node_2.Ty, 0, rel_tol=1e-5, abs_tol=1e-9)
-                and not el.all_q_load
+                and math.isclose(el.all_qp_load[0], 0, rel_tol=1e-5, abs_tol=1e-9)
+                and math.isclose(el.all_qp_load[1], 0, rel_tol=1e-5, abs_tol=1e-9)
             ):
                 # If True there is no bending moment, so no need for plotting.
                 continue
@@ -602,15 +733,15 @@ class Plotter(PlottingValues):
                 node_results=node_results,
             )
 
-            if el.all_q_load:
+            if el.all_qp_load:
                 m_sag = min(el.bending_moment)
                 index = find_nearest(el.bending_moment, m_sag)[1]
-                offset = -self.max_val_structure * 0.05
+                offset = self.max_val_structure * -0.05
 
                 if verbosity == 0:
                     x = axis_values[0][index] + np.sin(-el.angle) * offset
                     y = axis_values[1][index] + np.cos(-el.angle) * offset
-                    self.one_fig.text(x, y, "%s" % round(m_sag, 1), fontsize=9)
+                    self.one_fig.text(x, y, f"{round(m_sag, 1)}", fontsize=9)
         if show:
             self.plot()
         else:
@@ -644,9 +775,11 @@ class Plotter(PlottingValues):
             if (
                 math.isclose(el.node_1.Ty, 0, rel_tol=1e-5, abs_tol=1e-9)
                 and math.isclose(el.node_2.Ty, 0, rel_tol=1e-5, abs_tol=1e-9)
-                and el.q_load is None
+                and math.isclose(el.all_qp_load[0], 0, rel_tol=1e-5, abs_tol=1e-9)
+                and math.isclose(el.all_qp_load[1], 0, rel_tol=1e-5, abs_tol=1e-9)
             ):
-                # If True there is no bending moment and no shear, thus no shear force, so no need for plotting.
+                # If True there is no bending moment and no shear, thus no shear force,
+                # so no need for plotting.
                 continue
             axis_values = plot_values_shear_force(el, factor)
             shear_1 = el.shear_force[0]
@@ -699,7 +832,7 @@ class Plotter(PlottingValues):
                     self.one_fig.text(
                         x,
                         y,
-                        "R=%s" % round(node.Fx, 2),
+                        f"R={round(node.Fx, 2)}",
                         color="k",
                         fontsize=9,
                         zorder=10,
@@ -730,7 +863,7 @@ class Plotter(PlottingValues):
                     self.one_fig.text(
                         x,
                         y,
-                        "R=%s" % round(node.Fz, 2),
+                        f"R={round(node.Fz, 2)}",
                         color="k",
                         fontsize=9,
                         zorder=10,
@@ -761,7 +894,7 @@ class Plotter(PlottingValues):
                     self.one_fig.text(
                         node.vertex.x + h * 0.2,
                         -node.vertex.z + h * 0.2,
-                        "T=%s" % round(node.Ty, 2),
+                        f"T={round(node.Ty, 2)}",
                         color="k",
                         fontsize=9,
                         zorder=10,
@@ -771,7 +904,7 @@ class Plotter(PlottingValues):
         else:
             return self.fig
 
-    def displacements(
+    def displacements(  # pylint: disable=arguments-renamed
         self,
         factor=None,
         figsize=None,
@@ -803,17 +936,19 @@ class Plotter(PlottingValues):
 
             if el.type == "general":
                 # index of the max deflection
-                index = np.argmax(np.abs(el.deflection))
+                x = np.linspace(el.vertex_1.x, el.vertex_2.x, el.deflection.size)
+                y = np.linspace(el.vertex_1.y, el.vertex_2.y, el.deflection.size)
+                xd, yd = plot_values_deflection(el, 1.0, linear)
+                deflection = ((xd - x) ** 2 + (yd - y) ** 2) ** 0.5
+                index = np.argmax(np.abs(deflection))
 
                 if verbosity == 0:
-                    x = (el.node_1.ux + el.node_2.ux) / 2
-                    y = (-el.node_1.uz + -el.node_2.uz) / 2
 
                     if index != 0 or index != el.deflection.size:
                         self._add_element_values(
                             axis_values[0],
                             axis_values[1],
-                            el.deflection[index] + (x ** 2 + y ** 2) ** 0.5,
+                            deflection[index],
                             index,
                             3,
                         )
