@@ -1,26 +1,26 @@
-from anastruct.sectionbase.sectionbase import section_base
 import math
+from anastruct.sectionbase.sectionbase import section_base
 
 
 def steel_section_properties(**kwargs):
-    steel_section = kwargs.get("steelsection", 'IPE 300')
-    orient = kwargs.get("orient", 'y')
+    steel_section = kwargs.get("steelsection", "IPE 300")
+    orient = kwargs.get("orient", "y")
     E = kwargs.get("E", 210e9)
     sw = kwargs.get("sw", False)
 
     param = section_base.get_section_parameters(steel_section)
-    EA = E * param['Ax']
-    if orient == 'y':
-        EI = E * param['Iy']
-    elif orient == 'z':
-        EI = E * param['Iz']
+    EA = E * param["Ax"]
+    if orient == "y":
+        EI = E * param["Iy"]
+    elif orient == "z":
+        EI = E * param["Iz"]
     else:
-        raise ValueError('Orient should be defined.')
+        raise ValueError("Orient should be defined.")
     if sw:
-        g = param['swdl']
+        g = param["swdl"]
     else:
         g = 0
-    section_name = '%s(%s)' % (steel_section, orient)
+    section_name = f"{steel_section}({orient})"
     return section_name, EA, EI, g
 
 
@@ -32,14 +32,14 @@ def rectangle_properties(**kwargs):
     sw = kwargs.get("sw", False)
 
     A = b * h
-    I = b * h ** 3 / 12
+    I = b * h**3 / 12
     EA = E * A
     EI = E * I
     if sw:
         g = A * gamma
     else:
         g = 0
-    section_name = 'rect %sx%s' % (b, h)
+    section_name = f"rect {b}x{h}"
     return section_name, EA, EI, g
 
 
@@ -49,13 +49,13 @@ def circle_properties(**kwargs):
     gamma = kwargs.get("gamma", 10000)
     sw = kwargs.get("sw", False)
 
-    A = math.pi * d ** 2 / 4
-    I = math.pi * d ** 4 / 64
+    A = math.pi * d**2 / 4
+    I = math.pi * d**4 / 64
     EA = E * A
     EI = E * I
     if sw:
         g = A * gamma
     else:
         g = 0
-    section_name = 'fi %s' % d
+    section_name = "fi {d}"
     return section_name, EA, EI, g
